@@ -12,14 +12,15 @@ from .core import grid
 from .core.dask import DaskMoveDataFrame
 from .core.dataframe import MoveDataFrame
 from .core.pandas import PandasMoveDataFrame
+from .core.pandas_discrete import PandasDiscreteMoveDataFrame
 from .models.pattern_mining import clustering
 from .preprocessing import compression, filters, segmentation, stay_point_detection
+from .query import query
 from .semantic import semantic
 from .utils import (
     constants,
     conversions,
     datetime,
-    db,
     distances,
     integration,
     math,
