@@ -46,6 +46,10 @@ class MoveDataFrameAbstractModel(abc.ABC):
     def shape(self):
         pass
 
+    @abc.abstractmethod
+    def rename(self):
+        pass
+
     @abc.abstractmethod
     def len(self):
         pass
@@ -58,6 +62,10 @@ class MoveDataFrameAbstractModel(abc.ABC):
     def head(self):
         pass
 
+    @abc.abstractmethod
+    def tail(self):
+        pass
+
     @abc.abstractmethod
     def get_users_number(self):
         pass
@@ -75,7 +83,7 @@ class MoveDataFrameAbstractModel(abc.ABC):
         pass
 
     @abc.abstractmethod
-    def to_DataFrame(self):
+    def to_data_frame(self):
         pass
 
     @abc.abstractmethod
@@ -258,6 +266,10 @@ class MoveDataFrameAbstractModel(abc.ABC):
     def join(self):
         pass
 
+    @abc.abstractmethod
+    def merge(self):
+        pass
+
     @abc.abstractmethod
     def nunique(self):
         pass
