@@ -1,5 +1,3 @@
-import time
-
 import numpy as np
 
 from pymove.preprocessing import filters, segmentation, stay_point_detection
@@ -15,9 +13,10 @@ from pymove.utils.constants import (
     TIME_TO_PREV,
     TRAJ_ID,
 )
+from pymove.utils.log import timer_decorator
 
 
-def _end_create_operation(move_data, new_label, start_time, inplace):
+def _end_create_operation(move_data, new_label, inplace):
     """
     Returns the dataframe after create operation
 
@@ -25,8 +24,6 @@ def _end_create_operation(move_data, new_label, start_time, inplace):
         The input trajectories data.
     new_label: string
         The name of the new feature with detected deactivated signals.
-    start_time: float
-        Time when the operation started
     inplace : boolean
         if set to true the original dataframe will be altered to contain
         the result of the filtering, otherwise a copy will be returned.
@@ -39,15 +36,12 @@ def _end_create_operation(move_data, new_label, start_time, inplace):
     """
 
     print(move_data[new_label].value_counts())
-    print('\nTotal Time: %.2f seconds' % (time.time() - start_time))
-    print('-----------------------------------------------------\n')
-
     if not inplace:
         return move_data
 
 
 def _process_simple_filter(
-        move_data, new_label, feature, value, start_time, inplace
+        move_data, new_label, feature, value, inplace
 ):
     """
     Processes create operation with simple filter
@@ -60,8 +54,6 @@ def _process_simple_filter(
         Feature column to compare
     value: float
         Value to compare feature
-    start_time: float
-        Time when the operation started
     inplace : boolean
         if set to true the original dataframe will be altered to contain
         the result of the filtering, otherwise a copy will be returned.
@@ -81,10 +73,11 @@ def _process_simple_filter(
     move_data.at[idx, new_label] = True
 
     return _end_create_operation(
-        move_data, new_label, start_time, inplace
+        move_data, new_label, inplace
     )
 
 
+@timer_decorator
 def create_or_update_out_of_the_bbox(
         move_data, bbox, new_label=OUT_BBOX, inplace=True
 ):
@@ -117,7 +110,6 @@ def create_or_update_out_of_the_bbox(
             move_data = move_data[:]
 
         print('\nCreate or update boolean feature to detect points out of the bbox')
-        start_time = time.time()
         filtered_ = filters.by_bbox(move_data, bbox, filter_out=True)
 
         print('...Creating a new label named as %s' % new_label)
@@ -127,12 +119,13 @@ def create_or_update_out_of_the_bbox(
             move_data.at[filtered_.index, new_label] = True
 
         return _end_create_operation(
-            move_data, new_label, start_time, inplace
+            move_data, new_label, inplace
         )
     except Exception as e:
         raise e
 
 
+@timer_decorator
 def create_or_update_gps_deactivated_signal(
         move_data,
         max_time_between_adj_points=7200,
@@ -167,8 +160,7 @@ def create_or_update_gps_deactivated_signal(
         if not inplace:
             move_data = move_data[:]
 
-        start_time = time.time()
-        message = 'Create or update deactivated signal if time max > %s seconds\n'
+        message = 'Create or update deactivated signal if time max > %srs seconds\n'
         print(message % max_time_between_adj_points)
         move_data.generate_time_features()
 
@@ -177,13 +169,13 @@ def create_or_update_gps_deactivated_signal(
             new_label,
             TIME_TO_PREV,
             max_time_between_adj_points,
-            start_time,
             inplace
         )
     except Exception as e:
         raise e
 
 
+@timer_decorator
 def create_or_update_gps_jump(
         move_data,
         max_dist_between_adj_points=3000,
@@ -217,8 +209,7 @@ def create_or_update_gps_jump(
         if not inplace:
             move_data = move_data[:]
 
-        start_time = time.time()
-        message = 'Create or update jump if dist max > %s meters\n'
+        message = 'Create or update jump if dist max > %srs meters\n'
         print(message % max_dist_between_adj_points)
         move_data.generate_dist_features()
 
@@ -227,13 +218,13 @@ def create_or_update_gps_jump(
             new_label,
             DIST_TO_PREV,
             max_dist_between_adj_points,
-            start_time,
             inplace
         )
     except Exception as e:
         raise e
 
 
+@timer_decorator
 def create_or_update_short_trajectory(
         move_data,
         max_dist_between_adj_points=3000,
@@ -280,7 +271,6 @@ def create_or_update_short_trajectory(
             move_data = move_data[:]
 
         print('\nCreate or update short trajectories...')
-        start_time = time.time()
 
         segmentation.by_dist_time_speed(
             move_data,
@@ -297,17 +287,18 @@ def create_or_update_short_trajectory(
         move_data.loc[move_data[label_tid].isin(idx), new_label] = True
 
         return _end_create_operation(
-            move_data, new_label, start_time, inplace
+            move_data, new_label, inplace
         )
     except Exception as e:
         raise e
 
 
+@timer_decorator
 def create_or_update_gps_block_signal(
         move_data,
         max_time_stop=7200,
         new_label=BLOCK,
-        label_tid=TRAJ_ID,
+        label_tid=TID_PART,
         inplace=True
 ):
     """
@@ -341,9 +332,8 @@ def create_or_update_gps_block_signal(
         if not inplace:
             move_data = move_data[:]
 
-        message = 'Create or update block_signal if max time stop > %s seconds\n'
+        message = 'Create or update block_signal if max time stop > %srs seconds\n'
         print(message % max_time_stop)
-        start_time = time.time()
         segmentation.by_max_dist(
             move_data, max_dist_between_adj_points=0.0, label_new_tid=label_tid
         )
@@ -353,24 +343,26 @@ def create_or_update_gps_block_signal(
 
         move_data[new_label] = False
 
-        # SUM the segment block to dectect the id that has or more time stopped
+        # SUM the segment block to detect the id that has or more time stopped
         df_agg_tid = move_data.groupby(by=label_tid).agg({TIME_TO_PREV: 'sum'})
         filter_ = df_agg_tid[TIME_TO_PREV] >= max_time_stop
         idx = df_agg_tid[filter_].index
         move_data.loc[move_data[label_tid].isin(idx), new_label] = True
 
         return _end_create_operation(
-            move_data, new_label, start_time, inplace
+            move_data, new_label, inplace
         )
     except Exception as e:
         raise e
 
 
+@timer_decorator
 def filter_block_signal_by_repeated_amount_of_points(
         move_data,
         amount_max_of_points_stop=30.0,
         max_time_stop=7200,
         filter_out=False,
+        label_tid=TID_PART,
         inplace=False
 ):
     """
@@ -384,8 +376,11 @@ def filter_block_signal_by_repeated_amount_of_points(
         Maximum number of stopped points
     max_time_stop: float, optional, default 7200
         Maximum time allowed with speed 0
-    filter_out: boolean, optional, default True
-        Whether to keep or discard points with blocked signal
+    filter_out: boolean, optional, default False
+        If set to True, it will return trajectory points with blocked signal.
+    label_tid : str, optional, default 'tid_dist'
+        The label of the column containing the ids of the formed segments.
+        Is the new slitted id.
     inplace : boolean, optional, default True
         if set to true the original dataframe will be altered to contain
         the result of the filtering, otherwise a copy will be returned.
@@ -404,16 +399,20 @@ def filter_block_signal_by_repeated_amount_of_points(
             move_data = move_data[:]
 
         if BLOCK not in move_data:
-            create_or_update_gps_block_signal(move_data, max_time_stop)
+            create_or_update_gps_block_signal(
+                move_data, max_time_stop, label_tid=label_tid
+            )
+
+        df_count_tid = move_data.groupby(by=[label_tid]).sum()
+        filter_ = df_count_tid[BLOCK] > amount_max_of_points_stop
 
-        df_count_tid = move_data.groupby(by=[BLOCK]).count()
-        filter_ = df_count_tid > amount_max_of_points_stop
         if filter_out:
-            idx = df_count_tid[filter_].index
-        else:
             idx = df_count_tid[~filter_].index
+        else:
+            idx = df_count_tid[filter_].index
 
-        move_data = move_data[move_data[BLOCK].isin(idx)]
+        filter_ = move_data[move_data[label_tid].isin(idx)].index
+        move_data.drop(index=filter_, inplace=True)
         if not inplace:
             return move_data
 
@@ -421,10 +420,12 @@ def filter_block_signal_by_repeated_amount_of_points(
         raise e
 
 
+@timer_decorator
 def filter_block_signal_by_time(
         move_data,
         max_time_stop=7200,
         filter_out=False,
+        label_tid=TID_PART,
         inplace=False
 ):
     """
@@ -436,8 +437,11 @@ def filter_block_signal_by_time(
         The input trajectories data.
     max_time_stop: float, optional, default 7200
         Maximum time allowed with speed 0
-    filter_out: boolean, optional, default True
-        Whether to keep or discard points with blocked signal
+    filter_out: boolean, optional, default False
+        If set to True, it will return trajectory points with blocked signal.
+    label_tid : str, optional, default 'tid_dist'
+        The label of the column containing the ids of the formed segments.
+        Is the new slitted id.
     inplace : boolean, optional, default True
         if set to true the original dataframe will be altered to contain
         the result of the filtering, otherwise a copy will be returned.
@@ -456,16 +460,22 @@ def filter_block_signal_by_time(
             move_data = move_data[:]
 
         if BLOCK not in move_data:
-            create_or_update_gps_block_signal(move_data, max_time_stop)
+            create_or_update_gps_block_signal(
+                move_data, max_time_stop, label_tid=label_tid
+            )
+
+        df_agg_tid = move_data.groupby(by=label_tid).agg(
+            {TIME_TO_PREV: 'sum', BLOCK: 'sum'}
+        )
+        filter_ = (df_agg_tid[TIME_TO_PREV] > max_time_stop) & (df_agg_tid[BLOCK])
 
-        df_agg_tid = move_data.groupby(by=BLOCK).agg({TIME_TO_PREV: 'sum'})
-        filter_ = df_agg_tid[TIME_TO_PREV] > max_time_stop
         if filter_out:
-            idx = df_agg_tid[filter_].index
+            idx = df_agg_tid[~filter_].index
         else:
             idx = df_agg_tid[filter_].index
 
-        move_data = move_data[move_data[BLOCK].isin(idx)]
+        filter_ = move_data[move_data[label_tid].isin(idx)].index
+        move_data.drop(index=filter_, inplace=True)
         if not inplace:
             return move_data
 
@@ -473,8 +483,11 @@ def filter_block_signal_by_time(
         raise e
 
 
+@timer_decorator
 def filter_longer_time_to_stop_segment_by_id(
         move_data,
+        dist_radius=30,
+        time_radius=900,
         label_id=TRAJ_ID,
         label_segment_stop=SEGMENT_STOP,
         filter_out=False,
@@ -487,12 +500,20 @@ def filter_longer_time_to_stop_segment_by_id(
     __________
     move_data: dataFrame
         The input trajectories data.
+    dist_radius : float, optional, default 30
+        The first step in this function is segmenting the trajectory.
+        The segments are used to find the stop points.
+        The dist_radius defines the distance used in the segmentation.
+    time_radius :  float, optional, default 900
+        The time_radius used to determine if a segment is a stop.
+        If the user stayed in the segment for a time
+        greater than time_radius, than the segment is a stop.
     label_tid : str, optional, default 'id'
         The label of the column containing the ids of the formed segments.
         Is the new slitted id.
     label_segment_stop: str, optional, default 'segment_stop'
     filter_out: boolean, optional, default True
-        Whether to keep or discard points with blocked signal
+        If set to True, it will return trajectory points with longer time.
     inplace : boolean, optional, default True
         if set to true the original dataframe will be altered to contain
         the result of the filtering, otherwise a copy will be returned.
@@ -511,7 +532,7 @@ def filter_longer_time_to_stop_segment_by_id(
 
         if label_segment_stop not in move_data:
             stay_point_detection.create_or_update_move_stop_by_dist_time(
-                move_data
+                move_data, dist_radius, time_radius
             )
 
         df_agg_id_stop = move_data.groupby(
@@ -523,12 +544,13 @@ def filter_longer_time_to_stop_segment_by_id(
         )[TIME_TO_PREV].idxmax()
 
         if filter_out:
-            segments = df_agg_id_stop.loc[filter_]
-        else:
             segments = df_agg_id_stop.loc[~df_agg_id_stop.index.isin(filter_)]
+        else:
+            segments = df_agg_id_stop.loc[df_agg_id_stop.index.isin(filter_)]
         segments = segments[label_segment_stop]
 
-        move_data = move_data[move_data[label_segment_stop].isin(segments)]
+        filter_ = move_data[move_data[label_segment_stop].isin(segments)].index
+        move_data.drop(index=filter_, inplace=True)
         if not inplace:
             return move_data
 
