@@ -204,11 +204,13 @@ def test_convert_one_index_grid_to_two():
 
 
 def test_create_one_polygon_to_point_on_grid():
-    expected = [[39.984094, 116.3193713464802],
-                [39.984229346480184, 116.3193713464802],
-                [39.984229346480184, 116.31950669296039],
-                [39.984094, 116.31950669296039],
-                [39.984094, 116.3193713464802]]
+    expected = [
+        [116.3193713464802, 39.984094],
+        [116.3193713464802, 39.984229346480184],
+        [116.31950669296039, 39.984229346480184],
+        [116.31950669296039, 39.984094],
+        [116.3193713464802, 39.984094]
+    ]
 
     grid = _default_grid()
 
@@ -222,26 +224,42 @@ def test_create_one_polygon_to_point_on_grid():
 def test_create_all_polygons_to_all_point_on_grid():
     expected = DataFrame(
         data=[
-            [1, 0, 0, Polygon(((39.984094, 116.319236),
-                               (39.984229346480184, 116.319236),
-                               (39.984229346480184, 116.3193713464802),
-                               (39.984094, 116.3193713464802),
-                               (39.984094, 116.319236)))],
-            [1, 0, 1, Polygon(((39.984094, 116.319236),
-                               (39.984229346480184, 116.319236),
-                               (39.984229346480184, 116.3193713464802),
-                               (39.984094, 116.3193713464802),
-                               (39.984094, 116.319236)))],
-            [1, 4, 4, Polygon(((39.984094, 116.3193713464802),
-                               (39.984229346480184, 116.3193713464802),
-                               (39.984229346480184, 116.31950669296039),
-                               (39.984094, 116.31950669296039),
-                               (39.984094, 116.3193713464802)))],
-            [1, 3, 3, Polygon(((39.984094, 116.3193713464802),
-                               (39.984229346480184, 116.3193713464802),
-                               (39.984229346480184, 116.31950669296039),
-                               (39.984094, 116.31950669296039),
-                               (39.984094, 116.3193713464802)))],
+            [
+                1, 0, 0, Polygon((
+                    (116.319236, 39.984094),
+                    (116.319236, 39.984229346480184),
+                    (116.3193713464802, 39.984229346480184),
+                    (116.3193713464802, 39.984094),
+                    (116.319236, 39.984094)
+                ))
+            ],
+            [
+                1, 0, 1, Polygon((
+                    (116.319236, 39.984094),
+                    (116.319236, 39.984229346480184),
+                    (116.3193713464802, 39.984229346480184),
+                    (116.3193713464802, 39.984094),
+                    (116.319236, 39.984094)
+                ))
+            ],
+            [
+                1, 4, 4, Polygon((
+                    (116.3193713464802, 39.984094),
+                    (116.3193713464802, 39.984229346480184),
+                    (116.31950669296039, 39.984229346480184),
+                    (116.31950669296039, 39.984094),
+                    (116.3193713464802, 39.984094)
+                ))
+            ],
+            [
+                1, 3, 3, Polygon((
+                    (116.3193713464802, 39.984094),
+                    (116.3193713464802, 39.984229346480184),
+                    (116.31950669296039, 39.984229346480184),
+                    (116.31950669296039, 39.984094),
+                    (116.3193713464802, 39.984094)
+                ))
+            ],
         ],
         columns=['id', 'index_grid_lat', 'index_grid_lon', 'polygon'],
         index=[0, 2, 5, 7],
@@ -286,17 +304,19 @@ def test_save_grid_pkl(tmpdir):
     grid.save_grid_pkl(filename_write_default)
 
     saved_grid = grid.read_grid_pkl(filename_write_default)
+    saved_grid = saved_grid.get_grid()
 
     assert_equal(saved_grid, expected)
 
 
 def read_grid_pkl(tmpdir):
-    expected = {'lon_min_x': 116.319236,
-                'lat_min_y': 39.984094,
-                'grid_size_lat_y': 5,
-                'grid_size_lon_x': 5,
-                'cell_size_by_degree': 0.0001353464801860623
-                }
+    expected = {
+        'lon_min_x': 116.319236,
+        'lat_min_y': 39.984094,
+        'grid_size_lat_y': 5,
+        'grid_size_lon_x': 5,
+        'cell_size_by_degree': 0.0001353464801860623
+    }
     d = tmpdir.mkdir('core')
 
     file_write_default = d.join('test_read_grid.pkl')
@@ -310,5 +330,6 @@ def read_grid_pkl(tmpdir):
         joblib.dump(grid.get_grid(), f)
 
     saved_grid = grid.read_grid_pkl(filename_write_default)
+    saved_grid = saved_grid.get_grid()
 
     assert_equal(saved_grid, expected)
