@@ -7,7 +7,6 @@ from folium.plugins import FastMarkerCluster, HeatMap, HeatMapWithTime, MarkerCl
 from pymove.preprocessing import filters
 from pymove.utils import distances
 from pymove.utils.constants import (
-    COLORS,
     COUNT,
     DATE,
     DATETIME,
@@ -118,8 +117,8 @@ def create_base_map(
     """
 
     if lat_origin is None and lon_origin is None:
-        lat_origin = move_data.iloc[0][LATITUDE]
-        lon_origin = move_data.iloc[0][LONGITUDE]
+        lat_origin = move_data[LATITUDE].median()
+        lon_origin = move_data[LONGITUDE].median()
     base_map = folium.Map(
         location=[lat_origin, lon_origin],
         control_scale=True,
@@ -129,28 +128,6 @@ def create_base_map(
     return base_map
 
 
-def generate_base_map(default_location, default_zoom_start=12):
-    """
-    Generate a folium map.
-    Parameters
-    ----------
-    default_location : tuple.
-        Represents coordinates lat, lon which will be the center of the map.
-    default_zoom_start : int, optional, default 12.
-        Represents the zoom which will be the center of the map.
-    Returns
-    -------
-    base_map : folium.folium.Map.
-        Represents a folium map.
-    """
-    base_map = folium.Map(
-        location=default_location,
-        control_scale=True,
-        zoom_start=default_zoom_start
-    )
-    return base_map
-
-
 def heatmap(
     move_data,
     n_rows=None,
@@ -538,11 +515,19 @@ def plot_markers(
     if n_rows is None:
         n_rows = move_data.shape[0]
 
-    _add_begin_end_markers_to_folium_map(move_data.iloc[:n_rows], base_map)
-
-    for row in move_data.iloc[1: n_rows - 1].iterrows():
+    for i, row in enumerate(move_data.iloc[:n_rows].iterrows()):
+        if i == 0:
+            se = '<b>START</b>\n'
+            color = 'green'
+        elif i == n_rows - 1:
+            se = '<b>END\ns</b>\n'
+            color = 'red'
+        else:
+            se = ''
+            color = 'blue'
         pop = (
-            '<b>Latitude:</b> '
+            se
+            + '<b>Latitude:</b> '
             + str(row[1][LATITUDE])
             + '\n<b>Longitude:</b> '
             + str(row[1][LONGITUDE])
@@ -551,8 +536,10 @@ def plot_markers(
         )
         folium.Marker(
             location=[row[1][LATITUDE], row[1][LONGITUDE]],
+            color=color,
             clustered_marker=True,
             popup=pop,
+            icon=folium.Icon(color=color)
         ).add_to(base_map)
 
     if save_as_html:
@@ -562,7 +549,7 @@ def plot_markers(
 
 
 def _filter_and_generate_colors(
-    move_data, id_=None, n_rows=None, color=None
+    move_data, id_=None, n_rows=None, color=None, color_by_id=None
 ):
     """
     Filters the dataframe and generate colors for folium map.
@@ -577,6 +564,8 @@ def _filter_and_generate_colors(
         Represents number of data rows that are will plot.
     color: string or None.
         The color of the trajectory, of each trajectory or a colormap
+    color_by_id: dict, optional, default None.
+        A dictionary where the key is the trajectory id and value is a color(string).
 
     Returns
     -------
@@ -611,18 +600,26 @@ def _filter_and_generate_colors(
         ids = mv_df[TRAJ_ID].unique()
 
         if isinstance(color, str):
-            cmap_ = get_cmap(color)
-            num = cmap_.N
-            colors = [
-                cmap_hex_color(cmap_, (i % num))
-                for i, _ in enumerate(ids)
-            ]
-            diff = (len(ids) // len(colors)) + 1
-            colors *= diff
+            try:
+                cmap_ = get_cmap(color)
+                num = cmap_.N
+                colors = [
+                    cmap_hex_color(cmap_, (i % num))
+                    for i, _ in enumerate(ids)
+                ]
+                diff = (len(ids) // len(colors)) + 1
+                colors *= diff
+            except ValueError:
+                colors = [color]
         else:
             colors = color[:]
         items = [*zip(ids, colors)]
-
+        if color_by_id is not None:
+            keys = color_by_id.keys()
+            for key in keys:
+                for count, item in enumerate(items):
+                    if str(key) == str(item[0]):
+                        items[count] = (item[0], color_by_id[key])
     return mv_df, items
 
 
@@ -657,7 +654,7 @@ def _filter_generated_feature(move_data, feature, values):
     return mv_df
 
 
-def _add_begin_end_markers_to_folium_map(move_data, base_map):
+def _add_begin_end_markers_to_folium_map(move_data, base_map, color=None, _id=None):
     """
     Adds a green marker to beginning of the trajectory and a red marker to the
     end of the trajectory.
@@ -668,24 +665,37 @@ def _add_begin_end_markers_to_folium_map(move_data, base_map):
         Input trajectory data.
     base_map : folium.folium.Map, optional, default None.
         Represents the folium map. If not informed, a new map is generated.
-
+    color : string, optional, default None
+        Color of the markers
+    id: int, optional, default None
+        Id of the trajectory
     """
 
+    points = folium.map.FeatureGroup(
+        'The start and end points of trajectory {}'.format(_id or '')
+    )
+
     folium.Marker(
         location=[move_data.iloc[0][LATITUDE], move_data.iloc[0][LONGITUDE]],
         color='green',
         clustered_marker=True,
         popup='Início',
-        icon=folium.Icon(color='green', icon='info-sign'),
-    ).add_to(base_map)
+        icon=plugins.BeautifyIcon(
+            icon='play', icon_shape='marker', background_color=color or 'green'
+        )
+    ).add_to(points)
 
     folium.Marker(
         location=[move_data.iloc[-1][LATITUDE], move_data.iloc[-1][LONGITUDE]],
         color='red',
         clustered_marker=True,
         popup='Fim',
-        icon=folium.Icon(color='red', icon='info-sign'),
-    ).add_to(base_map)
+        icon=plugins.BeautifyIcon(
+            icon='times-circle', icon_shape='marker', background_color=color or 'red'
+        )
+    ).add_to(points)
+
+    base_map.add_child(points)
 
 
 def _add_trajectories_to_folium_map(
@@ -703,10 +713,10 @@ def _add_trajectories_to_folium_map(
     ----------
     move_data : pymove.core.MoveDataFrameAbstract subclass.
         Input trajectory data.
-    legend: boolean, default True
-        Whether to add a legend to the map
     base_map : folium.folium.Map, optional, default None.
         Represents the folium map. If not informed, a new map is generated.
+    legend: boolean, default True
+        Whether to add a legend to the map
     save_as_html : bool, optional, default False.
         Represents if want save this visualization in a new file .html.
     filename : String, optional, default 'plot_trajectory_by_period.html'.
@@ -717,7 +727,7 @@ def _add_trajectories_to_folium_map(
     for _id, color in items:
         mv = move_data[move_data[TRAJ_ID] == _id]
 
-        _add_begin_end_markers_to_folium_map(move_data, base_map)
+        _add_begin_end_markers_to_folium_map(mv, base_map, color, _id)
 
         folium.PolyLine(
             mv[[LATITUDE, LONGITUDE]], color=color, weight=2.5, opacity=1
@@ -726,6 +736,8 @@ def _add_trajectories_to_folium_map(
     if legend:
         add_map_legend(base_map, 'Color by user ID', items)
 
+    folium.map.LayerControl(collapsed=False).add_to(base_map)
+
     if save_as_html:
         base_map.save(outfile=filename)
 
@@ -741,6 +753,7 @@ def plot_trajectories_with_folium(
     tile=TILES[0],
     save_as_html=False,
     color=None,
+    color_by_id=None,
     filename='plot_trajectories_with_folium.html',
 ):
     """
@@ -773,6 +786,8 @@ def plot_trajectories_with_folium(
     color : String, list, optional, default None.
         Represents line colors of visualization.
         Can be a single color name, a list of colors or a colormap name.
+    color_by_id: dict, optional, default None.
+        A dictionary where the key is the trajectory id and value is a color(string).
     filename : String, optional, default 'plot_trajectory_with_folium.html'.
         Represents the file name of new file .html.
 
@@ -793,8 +808,9 @@ def plot_trajectories_with_folium(
         )
 
     mv_df, items = _filter_and_generate_colors(
-        move_data, n_rows=n_rows, color=color
+        move_data, n_rows=n_rows, color=color, color_by_id=color_by_id
     )
+
     _add_trajectories_to_folium_map(
         mv_df, items, base_map, legend, save_as_html, filename
     )
@@ -813,7 +829,7 @@ def plot_trajectory_by_id_folium(
     base_map=None,
     tile=TILES[0],
     save_as_html=False,
-    color='black',
+    color='blue',
     filename='plot_trajectory_by_id_folium.html',
 ):
     """
@@ -892,6 +908,7 @@ def plot_trajectory_by_period(
     tile=TILES[0],
     save_as_html=False,
     color=None,
+    color_by_id=None,
     filename='plot_trajectory_by_period_with_folium.html',
 ):
     """
@@ -928,6 +945,8 @@ def plot_trajectory_by_period(
     color : String or List, optional, default None.
         Represents line colors of visualization.
         Can be a single color name, a list of colors or a colormap.
+    color_by_id: dict, optional, default None.
+        A dictionary where the key is the trajectory id and value is a color.
     filename : String, optional, default 'plot_trajectory_by_period.html'.
         Represents the file name of new file .html.
 
@@ -957,7 +976,7 @@ def plot_trajectory_by_period(
         move_data.generate_time_of_day_features()
 
     mv_df = _filter_generated_feature(move_data, PERIOD, [period])
-    mv_df, items = _filter_and_generate_colors(mv_df, id_, n_rows, color)
+    mv_df, items = _filter_and_generate_colors(mv_df, id_, n_rows, color, color_by_id)
     _add_trajectories_to_folium_map(
         mv_df, items, base_map, legend, save_as_html, filename
     )
@@ -978,6 +997,7 @@ def plot_trajectory_by_day_week(
     tile=TILES[0],
     save_as_html=False,
     color=None,
+    color_by_id=None,
     filename='plot_trajectory_by_day_week.html',
 ):
     """
@@ -1014,6 +1034,8 @@ def plot_trajectory_by_day_week(
     color : String or List, optional, default None.
         Represents line colors of visualization.
         Can be a single color name, a list of colors or a colormap.
+    color_by_id: dict, optional, default None.
+        A dictionary where the key is the trajectory id and value is a color.
     filename : String, optional, default 'plot_trajectory_by_day_week.html'.
         Represents the file name of new file .html.
 
@@ -1043,7 +1065,7 @@ def plot_trajectory_by_day_week(
         move_data.generate_day_of_the_week_features()
 
     mv_df = _filter_generated_feature(move_data, DAY, [day_week])
-    mv_df, items = _filter_and_generate_colors(mv_df, id_, n_rows, color)
+    mv_df, items = _filter_and_generate_colors(mv_df, id_, n_rows, color, color_by_id)
     _add_trajectories_to_folium_map(
         mv_df, items, base_map, legend, save_as_html, filename
     )
@@ -1065,6 +1087,7 @@ def plot_trajectory_by_date(
     tile=TILES[0],
     save_as_html=False,
     color=None,
+    color_by_id=None,
     filename='plot_trajectory_by_date.html',
 ):
     """
@@ -1103,6 +1126,8 @@ def plot_trajectory_by_date(
     color : String or List, optional, default None.
         Represents line colors of visualization.
         Can be a single color name, a list of colors or a colormap.
+    color_by_id: dict, optional, default None.
+        A dictionary where the key is the trajectory id and value is a color.
     filename : String, optional, default 'plot_trejectory_with_folium.html'.
         Represents the file name of new file .html.
 
@@ -1139,7 +1164,7 @@ def plot_trajectory_by_date(
         move_data.generate_date_features()
 
     mv_df = _filter_generated_feature(move_data, DATE, [start_date, end_date])
-    mv_df, items = _filter_and_generate_colors(mv_df, id_, n_rows, color)
+    mv_df, items = _filter_and_generate_colors(mv_df, id_, n_rows, color, color_by_id)
     _add_trajectories_to_folium_map(
         mv_df, items, base_map, legend, save_as_html, filename
     )
@@ -1161,6 +1186,7 @@ def plot_trajectory_by_hour(
     tile=TILES[0],
     save_as_html=False,
     color=None,
+    color_by_id=None,
     filename='plot_trajectory_by_hour.html',
 ):
     """
@@ -1199,6 +1225,8 @@ def plot_trajectory_by_hour(
     color : String or List, optional, default None.
         Represents line colors of visualization.
         Can be a single color name, a list of colors or a colormap.
+    color_by_id: dict, optional, default None.
+        A dictionary where the key is the trajectory id and value is a color.
     filename : String, optional, default 'plot_trajectory_by_hour.html'.
         Represents the file name of new file .html.
 
@@ -1228,7 +1256,7 @@ def plot_trajectory_by_hour(
         move_data.generate_hour_features()
 
     mv_df = _filter_generated_feature(move_data, HOUR, [start_hour, end_hour])
-    mv_df, items = _filter_and_generate_colors(mv_df, id_, n_rows, color)
+    mv_df, items = _filter_and_generate_colors(mv_df, id_, n_rows, color, color_by_id)
     _add_trajectories_to_folium_map(
         mv_df, items, base_map, legend, save_as_html, filename
     )
@@ -1346,6 +1374,55 @@ def plot_stops(
         return base_map
 
 
+def plot_bbox(
+    bbox_tuple,
+    tiles=TILES[0],
+    color='red',
+    save_map=False,
+    file='bbox.html'
+):
+    """
+    Plots a bbox using Folium.
+
+    Parameters
+    ----------
+    bbox_tuple : tuple.
+        Represents a bound box, that is a tuple of 4 values with the
+        min and max limits of latitude e longitude.
+    tiles : String, optional, default 'OpenStreetMap'.
+    color : String, optional, default 'red'.
+        Represents color of lines on map.
+    file : String, optional, default 'bbox.html'.
+        Represents filename.
+    save_map: Boolean, optional, default False.
+        Wether to save the bbox folium map.
+
+    Returns
+    --------
+    folium map with bounding box
+
+    """
+
+    m = folium.Map(tiles=tiles)
+    m.fit_bounds(
+        [[bbox_tuple[0], bbox_tuple[1]], [bbox_tuple[2], bbox_tuple[3]]]
+    )
+    points_ = [
+        (bbox_tuple[0], bbox_tuple[1]),
+        (bbox_tuple[0], bbox_tuple[3]),
+        (bbox_tuple[2], bbox_tuple[3]),
+        (bbox_tuple[2], bbox_tuple[1]),
+        (bbox_tuple[0], bbox_tuple[1]),
+    ]
+    polygon = folium.PolyLine(points_, weight=3, color=color)
+    polygon.add_to(m)
+
+    if save_map:
+        m.save(file)
+
+    return m
+
+
 def _format_tags(line, slice_):
     """
     Create or format tags.
@@ -1372,6 +1449,7 @@ def _circle_maker(
     user_lon,
     slice_tags,
     user_point,
+    radius,
     map_
 ):
     """
@@ -1388,6 +1466,8 @@ def _circle_maker(
 
     user_point: String.
         Point color.
+    radius: Float.
+        radius size.
     map_: Folium map.
     """
 
@@ -1399,7 +1479,7 @@ def _circle_maker(
     tags_formated = _format_tags(line, slice_tags)
 
     folium.Circle(
-        radius=1,
+        radius=radius,
         location=[x, y],
         popup=tags_formated,
         color=user_point,
@@ -1407,160 +1487,12 @@ def _circle_maker(
     ).add_to(map_)
 
 
-def plot_incial_end_points(
-    list_rows,
-    user_lat,
-    user_lon,
-    slice_tags,
-    base_map,
-    map_
-):
-    """
-    Returns incial and end points.
-
-    Parameters
-    -----------
-    list_rows: List of DataFrame iter_tuple.
-    user_lat: String.
-        Latitude column name.
-    user_lon: String.
-        Longitude column name.
-    slice_tags:
-
-    user_point: String.
-        Point color.
-    map_: Folium map.
-    """
-
-    # plot the start user_point
-    line = list_rows[0][1]
-
-    tags_formated = _format_tags(line, slice_tags)
-
-    x = line[user_lat]
-    y = line[user_lon]
-
-    folium.Marker(
-        location=[x, y],
-        popup='START<br/>' + tags_formated,
-        icon=folium.Icon(color='green')
-    ).add_to(base_map)
-
-    line = list_rows[-1][1]
-
-    tags_formated = _format_tags(line, slice_tags)
-
-    x = line[user_lat]
-    y = line[user_lon]
-
-    folium.Marker(
-        location=[x, y],
-        popup='END<br/>' + tags_formated,
-        icon=folium.Icon(color='red', icon='info-sign')
-    ).add_to(base_map)
-
-
-def add_traj_folium(
+def plot_points_folium(
     move_data,
     user_lat=LATITUDE,
     user_lon=LONGITUDE,
     user_point=USER_POINT,
-    line_color=LINE_COLOR,
-    user_datetime=DATETIME,
-    sort=False,
-    base_map=None,
-    slice_tags=None,
-    tiles=TILES[0]
-):
-    """
-    Receives a MoveDataFrame and returns a folium map with the trajectories plots.
-
-    Parameters
-    ----------
-    move_data: Dataframe
-        Trajectory data.
-    user_lat: String, optional, default 'lat'.
-        Latitude column name.
-    user_lon: String, optional, default 'lon'.
-        Longitude column name.
-    user_point: String, optional, default 'purple'.
-        User point color.
-    line_color: String, optional, default 'blue'.
-        Line color.
-    user_datetime: String, optional, default 'datetime'.
-        Datetime column name.
-    sort:Boolean, optional, default False.
-        If True the data will be sorted.
-    base_map: Folium map, optional, default None.
-        A folium map to plot the trajectories. If None a map will be created.
-    slice_tags: optional, default None.
-    tiles: string, optional, default 'OpenStreetMap'.
-        The map type.
-
-    Returns
-    -------
-        A folium map.
-    """
-
-    if not slice_tags:
-        slice_tags = move_data.columns
-
-    # If not have a map a map is create with mean to lat and lon
-    if not base_map:
-        initial_lat = move_data[user_lat].mean()
-        initial_lon = move_data[user_lon].mean()
-        base_map = create_base_map(
-            move_data=move_data,
-            lat_origin=initial_lat,
-            lon_origin=initial_lon,
-            tile=tiles
-        )
-
-    # if needs sort the data
-    if sort:
-        move_data.sort_values(user_datetime, inplace=True)
-
-    # plot the lines
-    user_points = list(zip(move_data[user_lat], move_data[user_lon]))
-
-    folium.PolyLine(
-        user_points,
-        color=line_color,
-        weight=2
-    ).add_to(base_map)
-
-    list(
-        map(
-            lambda x: _circle_maker(
-                x,
-                user_lat,
-                user_lon,
-                slice_tags,
-                user_point,
-                base_map
-            ),
-            move_data.iterrows()
-        )
-    )
-
-    plot_incial_end_points(
-        list(move_data.iterrows()),
-        user_lat,
-        user_lon,
-        slice_tags,
-        base_map,
-        base_map
-    )
-
-    return base_map
-
-
-def add_point_folium(
-    move_data,
-    user_lat=LATITUDE,
-    user_lon=LONGITUDE,
-    user_point=USER_POINT,
-    poi_point=POI_POINT,
+    radius=2,
     base_map=None,
     slice_tags=None,
     tiles=TILES[0]
@@ -1579,8 +1511,8 @@ def add_point_folium(
         Longitude column name.
     user_point: String, optional, default 'orange'.
         The point color.
-    poi_point: String, optional, default 'red'.
-        Poi point color.
+    radius: Float, optional, default 2.
+        radius size.
     sort:Boolean, optional, default False.
         If True the data will be sorted.
     base_map: Folium map, optional, default None.
@@ -1616,6 +1548,7 @@ def add_point_folium(
                 user_lon,
                 slice_tags,
                 user_point,
+                radius,
                 base_map
             ),
             move_data.iterrows()
@@ -1625,13 +1558,15 @@ def add_point_folium(
     return base_map
 
 
-def add_poi_folium(
+def plot_poi_folium(
     move_data,
     poi_lat=LATITUDE,
     poi_lon=LONGITUDE,
     poi_point=POI_POINT,
+    radius=2,
     base_map=None,
-    slice_tags=None
+    slice_tags=None,
+    tiles=TILES[0]
 ):
 
     """
@@ -1647,51 +1582,37 @@ def add_poi_folium(
         Longitude column name.
     poi_point: String, optional, default 'red'.
         Poi point color.
+    radius: Float, optional, default 2.
+        radius size.
     base_map: Folium map, optional, default None.
         A folium map to plot. If None a map. If None a map will be created.
+    slice_tags: optional, default None.
+    tiles: string, optional, default 'OpenStreetMap'.
+        The map type.
 
     Returns
     -------
     folium.folium.Map.
         Represents a folium map with visualization.
     """
-
-    if not slice_tags:
-        slice_tags = move_data.columns
-
-    # If not have a map a map is create with mean to lat and lon
-    if not base_map:
-        initial_lat = move_data[poi_lat].mean()
-        initial_lon = move_data[poi_lon].mean()
-        base_map = create_base_map(
-            move_data=move_data,
-            lat_origin=initial_lat,
-            lon_origin=initial_lon
-        )
-
-    list(
-        map(
-            lambda x: _circle_maker(
-                x,
-                poi_lat,
-                poi_lon,
-                slice_tags,
-                poi_point,
-                base_map
-            ),
-            move_data.iterrows()
-        )
+    return plot_points_folium(
+        move_data,
+        user_lat=poi_lat,
+        user_lon=poi_lon,
+        user_point=poi_point,
+        radius=radius,
+        base_map=base_map,
+        slice_tags=slice_tags,
+        tiles=tiles
     )
 
-    return base_map
 
-
-def add_event_folium(
+def plot_event_folium(
     move_data,
     event_lat=LATITUDE,
     event_lon=LONGITUDE,
     event_point=EVENT_POINT,
-    radius=150,
+    radius=2,
     base_map=None,
     slice_tags=None,
     tiles=TILES[0]
@@ -1710,7 +1631,7 @@ def add_event_folium(
         Longitude column name.
     event_point: String, optional, default 'red'.
         Event color.
-    radius: Float, optional, default 150.
+    radius: Float, optional, default 2.
         radius size.
     base_map: Folium map, optional, default None.
         A folium map to plot. If None a map. If None a map will be created.
@@ -1720,36 +1641,17 @@ def add_event_folium(
     -------
     A folium map.
     """
-    if not slice_tags:
-        slice_tags = move_data.columns
-
-    # If not have a map a map is create with mean to lat and lon
-    if not base_map:
-        initial_lat = move_data[event_lat].mean()
-        initial_lon = move_data[event_lon].mean()
-        base_map = create_base_map(
-            move_data=move_data,
-            lat_origin=initial_lat,
-            lon_origin=initial_lon,
-            tile=tiles
-        )
-
-    list(
-        map(
-            lambda x: _circle_maker(
-                x,
-                event_lat,
-                event_lon,
-                slice_tags,
-                event_point,
-                base_map
-            ),
-            move_data.iterrows()
-        )
+    return plot_points_folium(
+        move_data,
+        user_lat=event_lat,
+        user_lon=event_lon,
+        user_point=event_point,
+        radius=radius,
+        base_map=base_map,
+        slice_tags=slice_tags,
+        tiles=tiles
     )
 
-    return base_map
-
 
 def show_trajs_with_event(
     move_data,
@@ -1878,7 +1780,7 @@ def show_trajs_with_event(
 
             move_data = df_event[df_event[event_id_] == event_id]
 
-            base_map = add_event_folium(
+            base_map = plot_event_folium(
                 move_data,
                 event_lat=event_lat_,
                 event_lon=event_lon_,
@@ -1916,15 +1818,18 @@ def show_trajs_with_event(
 
                 users.append(df_temp)
                 # add to folium map created
-                add_traj_folium(
+                base_map = plot_trajectories_with_folium(
+                    df_temp,
+                    color=[line_color],
+                    base_map=base_map
+                )
+                base_map = plot_points_folium(
                     df_temp,
                     user_lat=user_lat,
                     user_lon=user_lon,
                     user_point=user_point,
-                    line_color=line_color,
                     base_map=base_map,
-                    slice_tags=slice_subject_show,
-                    sort=True
+                    slice_tags=slice_subject_show
                 )
 
             # add to folium maps list: (id event, folium map, quantity of user in map, df)
@@ -2065,8 +1970,8 @@ def _create_geojson_features_line(
             'geometry': {
                 'type': 'LineString',
                 'coordinates': [
-                    [last['lon'], last['lat']],
-                    [row['lon'], row['lat']]
+                    [last[label_lon], last[label_lat]],
+                    [row[label_lon], row[label_lat]]
                 ]
 
             },
@@ -2092,9 +1997,9 @@ def _create_geojson_features_line(
 
 def plot_traj_timestamp_geo_json(
     move_data,
-    label_datetime=DATETIME,
     label_lat=LATITUDE,
     label_lon=LONGITUDE,
+    label_datetime=DATETIME,
     tiles=TILES[0]
 ):
     """
@@ -2105,7 +2010,7 @@ def plot_traj_timestamp_geo_json(
     move_data: DataFrame.
         Input trajectory data.
     label_datetime: string, optional, default 'datetime'.
-        date_time colunm label.
+        date_time column label.
     label_lat: string, optional, default 'lat'.
         latitude column label.
     label_lon: string, optional, default 'long'.
@@ -2117,7 +2022,12 @@ def plot_traj_timestamp_geo_json(
     -------
     A folium map.
     """
-    features = _create_geojson_features_line(move_data, label_datetime)
+    features = _create_geojson_features_line(
+        move_data,
+        label_lat=label_lat,
+        label_lon=label_lon,
+        label_datetime=label_datetime
+    )
     print('creating folium map')
     map_ = create_base_map(
         move_data=move_data,
@@ -2126,6 +2036,7 @@ def plot_traj_timestamp_geo_json(
         tile=tiles
     )
     print('Genering timestamp map')
+    print(features)
     plugins.TimestampedGeoJson(
         {
             'type': 'FeatureCollection',
